@@ -305,7 +305,8 @@ def generate_pair_no_neighbors(
         pair_MN = sample_MN_pair(X, n_MN)
         pair_FP = sample_FP_pair(X, pair_neighbors, n_neighbors, n_FP)
     else:
-        print("Triggered")
+        if verbose:
+            print("Triggered")
         pair_MN = sample_MN_pair_deterministic(X, n_MN, _RANDOM_STATE)
         pair_FP = sample_FP_pair_deterministic(X, pair_neighbors, n_neighbors, n_FP, _RANDOM_STATE)
     return pair_neighbors, pair_MN, pair_FP
@@ -493,7 +494,7 @@ class PaCMAP(BaseEstimator):
             warnings.warn("apply_pca = True for Hamming distance.")
         if not self.apply_pca:
             print(
-                "running ANNOY on high-dimensional data. nearest-neighbor search may be slow!")
+                "Warning: running ANNOY Indexing on high-dimensional data. Nearest-neighbor search may be slow!")
 
     def fit(self, X, init=None, save_pairs=True):
         X = X.astype(np.float32)
